==> openshift-model-operatorhub-4.13.2-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1alpha1/InstallPlanStatusFluent.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import io.fabric8.kubernetes.api.model.ObjectReference;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.StringBuffer;
import io.fabric8.kubernetes.api.model.ObjectReferenceFluent;
import io.fabric8.kubernetes.api.model.ObjectReferenceBuilder;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

public interface InstallPlanStatusFluent<A extends InstallPlanStatusFluent<A>> extends Fluent<A> {


    
/**
 * This method has been deprecated, please use method buildAttenuatedServiceAccountRef instead.
 * @return The buildable object.
 */
@Deprecated public ObjectReference getAttenuatedServiceAccountRef();
    public ObjectReference buildAttenuatedServiceAccountRef();
    public A withAttenuatedServiceAccountRef(ObjectReference attenuatedServiceAccountRef);
    public Boolean hasAttenuatedServiceAccountRef();
    public InstallPlanStatusFluent.AttenuatedServiceAccountRefNested<A> withNewAttenuatedServiceAccountRef();
    public InstallPlanStatusFluent.AttenuatedServiceAccountRefNested<A> withNewAttenuatedServiceAccountRefLike(ObjectReference item);
    public InstallPlanStatusFluent.AttenuatedServiceAccountRefNested<A> editAttenuatedServiceAccountRef();
    public InstallPlanStatusFluent.AttenuatedServiceAccountRefNested<A> editOrNewAttenuatedServiceAccountRef();
    public InstallPlanStatusFluent.AttenuatedServiceAccountRefNested<A> editOrNewAttenuatedServiceAccountRefLike(ObjectReference item);
    public A addToBundleLookups(int index,BundleLookup item);
    public A setToBundleLookups(int index,BundleLookup item);
    public A addToBundleLookups(BundleLookup... items);
    public A addAllToBundleLookups(Collection<BundleLookup> items);
    public A removeFromBundleLookups(BundleLookup... items);
    public A removeAllFromBundleLookups(Collection<BundleLookup> items);
    public A removeMatchingFromBundleLookups(io.fabric8.kubernetes.api.builder.Predicate<BundleLookupBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildBundleLookups instead.
 * @return The buildable object.
 */
@Deprecated public List<BundleLookup> getBundleLookups();
    public List<BundleLookup> buildBundleLookups();
    public BundleLookup buildBundleLookup(int index);
    public BundleLookup buildFirstBundleLookup();
    public BundleLookup buildLastBundleLookup();
    public BundleLookup buildMatchingBundleLookup(io.fabric8.kubernetes.api.builder.Predicate<BundleLookupBuilder> predicate);
    public Boolean hasMatchingBundleLookup(io.fabric8.kubernetes.api.builder.Predicate<BundleLookupBuilder> predicate);
    public A withBundleLookups(List<BundleLookup> bundleLookups);
    public A withBundleLookups(BundleLookup... bundleLookups);
    public Boolean hasBundleLookups();
    public InstallPlanStatusFluent.BundleLookupsNested<A> addNewBundleLookup();
    public InstallPlanStatusFluent.BundleLookupsNested<A> addNewBundleLookupLike(BundleLookup item);
    public InstallPlanStatusFluent.BundleLookupsNested<A> setNewBundleLookupLike(int index,BundleLookup item);
    public InstallPlanStatusFluent.BundleLookupsNested<A> editBundleLookup(int index);
    public InstallPlanStatusFluent.BundleLookupsNested<A> editFirstBundleLookup();
    public InstallPlanStatusFluent.BundleLookupsNested<A> editLastBundleLookup();
    public InstallPlanStatusFluent.BundleLookupsNested<A> editMatchingBundleLookup(io.fabric8.kubernetes.api.builder.Predicate<BundleLookupBuilder> predicate);
    public A addToCatalogSources(int index,String item);
    public A setToCatalogSources(int index,String item);
    public A addToCatalogSources(String... items);
    public A addAllToCatalogSources(Collection<String> items);
    public A removeFromCatalogSources(String... items);
    public A removeAllFromCatalogSources(Collection<String> items);
    public List<String> getCatalogSources();
    public String getCatalogSource(int index);
    public String getFirstCatalogSource();
    public String getLastCatalogSource();
    public String getMatchingCatalogSource(io.fabric8.kubernetes.api.builder.Predicate<String> predicate);
    public Boolean hasMatchingCatalogSource(io.fabric8.kubernetes.api.builder.Predicate<String> predicate);
    public A withCatalogSources(List<String> catalogSources);
    public A withCatalogSources(String... catalogSources);
    public Boolean hasCatalogSources();
    public A addNewCatalogSource(String arg1);
    public A addNewCatalogSource(StringBuilder arg1);
    public A addNewCatalogSource(StringBuffer arg1);
    public A addToConditions(int index,InstallPlanCondition item);
    public A setToConditions(int index,InstallPlanCondition item);
    public A addToConditions(InstallPlanCondition... items);
    public A addAllToConditions(Collection<InstallPlanCondition> items);
    public A removeFromConditions(InstallPlanCondition... items);
    public A removeAllFromConditions(Collection<InstallPlanCondition> items);
    public A removeMatchingFromConditions(io.fabric8.kubernetes.api.builder.Predicate<InstallPlanConditionBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildConditions instead.
 * @return The buildable object.
 */
@Deprecated public List<InstallPlanCondition> getConditions();
    public List<InstallPlanCondition> buildConditions();
    public InstallPlanCondition buildCondition(int index);
    public InstallPlanCondition buildFirstCondition();
    public InstallPlanCondition buildLastCondition();
    public InstallPlanCondition buildMatchingCondition(io.fabric8.kubernetes.api.builder.Predicate<InstallPlanConditionBuilder> predicate);
    public Boolean hasMatchingCondition(io.fabric8.kubernetes.api.builder.Predicate<InstallPlanConditionBuilder> predicate);
    public A withConditions(List<InstallPlanCondition> conditions);
    public A withConditions(InstallPlanCondition... conditions);
    public Boolean hasConditions();
    public InstallPlanStatusFluent.ConditionsNested<A> addNewCondition();
    public InstallPlanStatusFluent.ConditionsNested<A> addNewConditionLike(InstallPlanCondition item);
    public InstallPlanStatusFluent.ConditionsNested<A> setNewConditionLike(int index,InstallPlanCondition item);
    public InstallPlanStatusFluent.ConditionsNested<A> editCondition(int index);
    public InstallPlanStatusFluent.ConditionsNested<A> editFirstCondition();
    public InstallPlanStatusFluent.ConditionsNested<A> editLastCondition();
    public InstallPlanStatusFluent.ConditionsNested<A> editMatchingCondition(io.fabric8.kubernetes.api.builder.Predicate<InstallPlanConditionBuilder> predicate);
    public String getPhase();
    public A withPhase(String phase);
    public Boolean hasPhase();
    public A withNewPhase(String arg1);
    public A withNewPhase(StringBuilder arg1);
    public A withNewPhase(StringBuffer arg1);
    public A addToPlan(int index,Step item);
    public A setToPlan(int index,Step item);
    public A addToPlan(Step... items);
    public A addAllToPlan(Collection<Step> items);
    public A removeFromPlan(Step... items);
    public A removeAllFromPlan(Collection<Step> items);
    public A removeMatchingFromPlan(io.fabric8.kubernetes.api.builder.Predicate<StepBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildPlan instead.
 * @return The buildable object.
 */
@Deprecated public List<Step> getPlan();
    public List<Step> buildPlan();
    public Step buildPlan(int index);
    public Step buildFirstPlan();
    public Step buildLastPlan();
    public Step buildMatchingPlan(io.fabric8.kubernetes.api.builder.Predicate<StepBuilder> predicate);
    public Boolean hasMatchingPlan(io.fabric8.kubernetes.api.builder.Predicate<StepBuilder> predicate);
    public A withPlan(List<Step> plan);
    public A withPlan(Step... plan);
    public Boolean hasPlan();
    public InstallPlanStatusFluent.PlanNested<A> addNewPlan();
    public InstallPlanStatusFluent.PlanNested<A> addNewPlanLike(Step item);
    public InstallPlanStatusFluent.PlanNested<A> setNewPlanLike(int index,Step item);
    public InstallPlanStatusFluent.PlanNested<A> editPlan(int index);
    public InstallPlanStatusFluent.PlanNested<A> editFirstPlan();
    public InstallPlanStatusFluent.PlanNested<A> editLastPlan();
    public InstallPlanStatusFluent.PlanNested<A> editMatchingPlan(io.fabric8.kubernetes.api.builder.Predicate<StepBuilder> predicate);
    public interface AttenuatedServiceAccountRefNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ObjectReferenceFluent<InstallPlanStatusFluent.AttenuatedServiceAccountRefNested<N>> {

        public N and();
        public N endAttenuatedServiceAccountRef();    }


    public interface BundleLookupsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,BundleLookupFluent<InstallPlanStatusFluent.BundleLookupsNested<N>> {

        public N and();
        public N endBundleLookup();    }


    public interface ConditionsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,InstallPlanConditionFluent<InstallPlanStatusFluent.ConditionsNested<N>> {

        public N and();
        public N endCondition();    }


    public interface PlanNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,StepFluent<InstallPlanStatusFluent.PlanNested<N>> {

        public N and();
        public N endPlan();    }


}

==> openshift-model-operatorhub-5.0.0-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1alpha1/InstallPlanStatusFluent.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import io.fabric8.kubernetes.api.model.ObjectReference;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.StringBuffer;
import io.fabric8.kubernetes.api.model.ObjectReferenceFluent;
import io.fabric8.kubernetes.api.model.ObjectReferenceBuilder;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

public interface InstallPlanStatusFluent<A extends InstallPlanStatusFluent<A>> extends Fluent<A> {


    
/**
 * This method has been deprecated, please use method buildAttenuatedServiceAccountRef instead.
 * @return The buildable object.
 */
@Deprecated public ObjectReference getAttenuatedServiceAccountRef();
    public ObjectReference buildAttenuatedServiceAccountRef();
    public A withAttenuatedServiceAccountRef(ObjectReference attenuatedServiceAccountRef);
    public Boolean hasAttenuatedServiceAccountRef();
    public InstallPlanStatusFluent.AttenuatedServiceAccountRefNested<A> withNewAttenuatedServiceAccountRef();
    public InstallPlanStatusFluent.AttenuatedServiceAccountRefNested<A> withNewAttenuatedServiceAccountRefLike(ObjectReference item);
    public InstallPlanStatusFluent.AttenuatedServiceAccountRefNested<A> editAttenuatedServiceAccountRef();
    public InstallPlanStatusFluent.AttenuatedServiceAccountRefNested<A> editOrNewAttenuatedServiceAccountRef();
    public InstallPlanStatusFluent.AttenuatedServiceAccountRefNested<A> editOrNewAttenuatedServiceAccountRefLike(ObjectReference item);
    public A addToBundleLookups(int index,BundleLookup item);
    public A setToBundleLookups(int index,BundleLookup item);
    public A addToBundleLookups(BundleLookup... items);
    public A addAllToBundleLookups(Collection<BundleLookup> items);
    public A removeFromBundleLookups(BundleLookup... items);
    public A removeAllFromBundleLookups(Collection<BundleLookup> items);
    public A removeMatchingFromBundleLookups(Predicate<BundleLookupBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildBundleLookups instead.
 * @return The buildable object.
 */
@Deprecated public List<BundleLookup> getBundleLookups();
    public List<BundleLookup> buildBundleLookups();
    public BundleLookup buildBundleLookup(int index);
    public BundleLookup buildFirstBundleLookup();
    public BundleLookup buildLastBundleLookup();
    public BundleLookup buildMatchingBundleLookup(Predicate<BundleLookupBuilder> predicate);
    public Boolean hasMatchingBundleLookup(Predicate<BundleLookupBuilder> predicate);
    public A withBundleLookups(List<BundleLookup> bundleLookups);
    public A withBundleLookups(BundleLookup... bundleLookups);
    public Boolean hasBundleLookups();
    public InstallPlanStatusFluent.BundleLookupsNested<A> addNewBundleLookup();
    public InstallPlanStatusFluent.BundleLookupsNested<A> addNewBundleLookupLike(BundleLookup item);
    public InstallPlanStatusFluent.BundleLookupsNested<A> setNewBundleLookupLike(int index,BundleLookup item);
    public InstallPlanStatusFluent.BundleLookupsNested<A> editBundleLookup(int index);
    public InstallPlanStatusFluent.BundleLookupsNested<A> editFirstBundleLookup();
    public InstallPlanStatusFluent.BundleLookupsNested<A> editLastBundleLookup();
    public InstallPlanStatusFluent.BundleLookupsNested<A> editMatchingBundleLookup(Predicate<BundleLookupBuilder> predicate);
    public A addToCatalogSources(int index,String item);
    public A setToCatalogSources(int index,String item);
    public A addToCatalogSources(String... items);
    public A addAllToCatalogSources(Collection<String> items);
    public A removeFromCatalogSources(String... items);
    public A removeAllFromCatalogSources(Collection<String> items);
    public List<String> getCatalogSources();
    public String getCatalogSource(int index);
    public String getFirstCatalogSource();
    public String getLastCatalogSource();
    public String getMatchingCatalogSource(Predicate<String> predicate);
    public Boolean hasMatchingCatalogSource(Predicate<String> predicate);
    public A withCatalogSources(List<String> catalogSources);
    public A withCatalogSources(String... catalogSources);
    public Boolean hasCatalogSources();
    public A addNewCatalogSource(String arg1);
    public A addNewCatalogSource(StringBuilder arg1);
    public A addNewCatalogSource(StringBuffer arg1);
    public A addToConditions(int index,InstallPlanCondition item);
    public A setToConditions(int index,InstallPlanCondition item);
    public A addToConditions(InstallPlanCondition... items);
    public A addAllToConditions(Collection<InstallPlanCondition> items);
    public A removeFromConditions(InstallPlanCondition... items);
    public A removeAllFromConditions(Collection<InstallPlanCondition> items);
    public A removeMatchingFromConditions(Predicate<InstallPlanConditionBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildConditions instead.
 * @return The buildable object.
 */
@Deprecated public List<InstallPlanCondition> getConditions();
    public List<InstallPlanCondition> buildConditions();
    public InstallPlanCondition buildCondition(int index);
    public InstallPlanCondition buildFirstCondition();
    public InstallPlanCondition buildLastCondition();
    public InstallPlanCondition buildMatchingCondition(Predicate<InstallPlanConditionBuilder> predicate);
    public Boolean hasMatchingCondition(Predicate<InstallPlanConditionBuilder> predicate);
    public A withConditions(List<InstallPlanCondition> conditions);
    public A withConditions(InstallPlanCondition... conditions);
    public Boolean hasConditions();
    public InstallPlanStatusFluent.ConditionsNested<A> addNewCondition();
    public InstallPlanStatusFluent.ConditionsNested<A> addNewConditionLike(InstallPlanCondition item);
    public InstallPlanStatusFluent.ConditionsNested<A> setNewConditionLike(int index,InstallPlanCondition item);
    public InstallPlanStatusFluent.ConditionsNested<A> editCondition(int index);
    public InstallPlanStatusFluent.ConditionsNested<A> editFirstCondition();
    public InstallPlanStatusFluent.ConditionsNested<A> editLastCondition();
    public InstallPlanStatusFluent.ConditionsNested<A> editMatchingCondition(Predicate<InstallPlanConditionBuilder> predicate);
    public String getPhase();
    public A withPhase(String phase);
    public Boolean hasPhase();
    public A withNewPhase(String arg1);
    public A withNewPhase(StringBuilder arg1);
    public A withNewPhase(StringBuffer arg1);
    public A addToPlan(int index,Step item);
    public A setToPlan(int index,Step item);
    public A addToPlan(Step... items);
    public A addAllToPlan(Collection<Step> items);
    public A removeFromPlan(Step... items);
    public A removeAllFromPlan(Collection<Step> items);
    public A removeMatchingFromPlan(Predicate<StepBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildPlan instead.
 * @return The buildable object.
 */
@Deprecated public List<Step> getPlan();
    public List<Step> buildPlan();
    public Step buildPlan(int index);
    public Step buildFirstPlan();
    public Step buildLastPlan();
    public Step buildMatchingPlan(Predicate<StepBuilder> predicate);
    public Boolean hasMatchingPlan(Predicate<StepBuilder> predicate);
    public A withPlan(List<Step> plan);
    public A withPlan(Step... plan);
    public Boolean hasPlan();
    public InstallPlanStatusFluent.PlanNested<A> addNewPlan();
    public InstallPlanStatusFluent.PlanNested<A> addNewPlanLike(Step item);
    public InstallPlanStatusFluent.PlanNested<A> setNewPlanLike(int index,Step item);
    public InstallPlanStatusFluent.PlanNested<A> editPlan(int index);
    public InstallPlanStatusFluent.PlanNested<A> editFirstPlan();
    public InstallPlanStatusFluent.PlanNested<A> editLastPlan();
    public InstallPlanStatusFluent.PlanNested<A> editMatchingPlan(Predicate<StepBuilder> predicate);
    public interface AttenuatedServiceAccountRefNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ObjectReferenceFluent<InstallPlanStatusFluent.AttenuatedServiceAccountRefNested<N>> {

        public N and();
        public N endAttenuatedServiceAccountRef();    }


    public interface BundleLookupsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,BundleLookupFluent<InstallPlanStatusFluent.BundleLookupsNested<N>> {

        public N and();
        public N endBundleLookup();    }


    public interface ConditionsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,InstallPlanConditionFluent<InstallPlanStatusFluent.ConditionsNested<N>> {

        public N and();
        public N endCondition();    }


    public interface PlanNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,StepFluent<InstallPlanStatusFluent.PlanNested<N>> {

        public N and();
        public N endPlan();    }


}
